pub struct AuxiliaryKey<R, const MAX_CHORDS: usize, const MAX_CHORD_SIZE: usize, const MAX_PRESSED_INDICES: usize> {
pub passthrough: R,
/* private fields */
}Expand description
Auxiliary chorded key (with a passthrough key).
The auxiliary keys are chorded keys, but don’t store the resolved chord key. (i.e. After te primary chorded key, the remaining keys in the chord are defined with auxiliary chorded keys).
Fields
passthrough: RThe passthrough key
Implementations
Sourceimpl<R, const MAX_CHORDS: usize, const MAX_CHORD_SIZE: usize, const MAX_PRESSED_INDICES: usize> AuxiliaryKey<R, MAX_CHORDS, MAX_CHORD_SIZE, MAX_PRESSED_INDICES>where
R: Copy,
impl<R, const MAX_CHORDS: usize, const MAX_CHORD_SIZE: usize, const MAX_PRESSED_INDICES: usize> AuxiliaryKey<R, MAX_CHORDS, MAX_CHORD_SIZE, MAX_PRESSED_INDICES>where
R: Copy,
Sourcepub fn new_pressed_key(
&self,
context: &Context<MAX_CHORDS, MAX_CHORD_SIZE, MAX_PRESSED_INDICES>,
keymap_index: u16,
) -> (PressedKeyResult<R, PendingKeyState<MAX_CHORDS, MAX_CHORD_SIZE, MAX_PRESSED_INDICES>, KeyState>, KeyEvents<Event>)
pub fn new_pressed_key( &self, context: &Context<MAX_CHORDS, MAX_CHORD_SIZE, MAX_PRESSED_INDICES>, keymap_index: u16, ) -> (PressedKeyResult<R, PendingKeyState<MAX_CHORDS, MAX_CHORD_SIZE, MAX_PRESSED_INDICES>, KeyState>, KeyEvents<Event>)
Constructs new pressed key.
Sourcepub const fn new(
passthrough: R,
) -> AuxiliaryKey<R, MAX_CHORDS, MAX_CHORD_SIZE, MAX_PRESSED_INDICES>
pub const fn new( passthrough: R, ) -> AuxiliaryKey<R, MAX_CHORDS, MAX_CHORD_SIZE, MAX_PRESSED_INDICES>
Constructs new auxiliary chorded key.