pub type TapHoldConfig = Config;Expand description
Type aliases for convenience.
Aliased Type
pub struct TapHoldConfig {
pub timeout: Option<u16>,
pub interrupt_response: InterruptResponse,
pub required_idle_time: Option<u16>,
}Fields
timeout: Option<u16>The timeout (in number of milliseconds) for a tap-hold key to resolve as hold.
When None, the tap/hold decision does not timeout;
the key resolves only on release (as tap) or interruption
(depending on InterruptResponse).
interrupt_response: InterruptResponseHow the tap-hold key should respond to interruptions.
required_idle_time: Option<u16>Amount of time (in milliseconds) the keymap must have been idle in order for tap hold to support ‘hold’ functionality.
This reduces disruption from unexpected hold resolutions when typing quickly.