Struct Key
pub struct Key {
pub usage_code: u8,
pub modifiers: KeyboardModifiers,
}Expand description
A consumer key: HID usage code with optional keyboard modifiers.
A modifiers value of zero is equivalent to no modifiers.
Fields
usage_code: u8HID consumer usage code.
modifiers: KeyboardModifiersKeyboard modifiers.
Implementations
impl Key
impl Key
pub const fn new_with_modifiers(
usage_code: u8,
modifiers: KeyboardModifiers,
) -> Key
pub const fn new_with_modifiers( usage_code: u8, modifiers: KeyboardModifiers, ) -> Key
Constructs a key with the given usage code and modifiers.