Function adaptive_rules
pub const fn adaptive_rules<const N: usize>(
rules: [AltRepeatRule; N],
) -> [AltRepeatRule; 8]Expand description
Builds a fixed-size adaptive rule array from a shorter const list (codegen helper).
pub const fn adaptive_rules<const N: usize>(
rules: [AltRepeatRule; N],
) -> [AltRepeatRule; 8]Builds a fixed-size adaptive rule array from a shorter const list (codegen helper).