Struct Context
pub struct Context { /* private fields */ }Expand description
Key Lock context: watching arm and at most one active virtual lock.
Implementations
impl Context
impl Context
pub fn reset(&mut self)
pub fn reset(&mut self)
Clear watching and the locked key (does not emit virtual releases).
pub fn is_watching(&self) -> bool
pub fn is_watching(&self) -> bool
Whether key lock is watching for the next key to lock.