LayerEvent

Enum LayerEvent 

pub enum LayerEvent {
    Activated(u32),
    Deactivated(u32),
    Toggled(u32),
    StickyActivated(u32),
    StickyReleased,
    StickyTimeout(u8),
    Set(ModifierBitset),
    SetDefault(u32),
    LockInvert(LayerLockTarget),
}
Events from ModifierKey which affect Context.

Variants



Activated(u32)

Activates the given layer (1-based; see LayerIndex).



Deactivated(u32)

Deactivates the given layer (1-based; see LayerIndex).



Toggled(u32)

Toggles the given layer (1-based; see LayerIndex).



StickyActivated(u32)

Activates the given layer as sticky (on sticky-mod press).



StickyReleased

Sticky layer modifier released without interruption (sticky committed).



StickyTimeout(u8)

Sticky layer timed out while unused.

The payload is a generation id used to ignore stale timeouts.



Set(ModifierBitset)

Sets the active layers to the given set of layers.



SetDefault(u32)

Changes the default layer.



LockInvert(LayerLockTarget)

Invert lock on the given LayerLockTarget.

See ModifierKey::Lock.