Key

Struct Key 

pub struct Key<R> {
    pub base: R,
    pub morphed: R,
    pub trigger_mods: KeyboardModifiers,
    pub keep_mods: KeyboardModifiers,
}
A key that picks a nested binding based on held modifiers.

Fields

base: R

Binding used when none of Self::trigger_mods are held.

morphed: R

Binding used when any of Self::trigger_mods is held.

trigger_mods: KeyboardModifiers

Modifiers that activate the morphed binding (any-of).

keep_mods: KeyboardModifiers

Subset of Self::trigger_mods to keep in the report on the morph path.

Implementations

Source

impl<R> Key<R>

pub const fn new( base: R, morphed: R, trigger_mods: KeyboardModifiers, keep_mods: KeyboardModifiers, ) -> Key<R>

Constructs a mod-conditioned key.

pub const fn suppress_mods(&self) -> KeyboardModifiers

Mods to suppress on the morph path (trigger \ keep).