Enum StickyKeyRelease
pub enum StickyKeyRelease {
OnModifiedKeyRelease,
OnNextKeyPress,
}Expand description
When the sticky modifiers release.
Variants
OnModifiedKeyRelease
Sticky modifiers release when the modified key is released.
OnNextKeyPress
Sticky modifiers release when a key is pressed after the modified key.