KeyOutput

Struct KeyOutput 

pub struct KeyOutput { /* private fields */ }
Struct for the output from KeyState.

Implementations



impl KeyOutput

pub const NO_OUTPUT: KeyOutput

A key output with no key code and no modifiers.

pub const fn from_usage(key_usage: KeyUsage) -> KeyOutput

Constructs a KeyOutput from a key usage.

pub const fn from_usage_with_modifiers( key_usage: KeyUsage, key_modifiers: KeyboardModifiers, ) -> KeyOutput

Constructs a KeyOutput from a key usage.

pub const fn from_key_code(key_code: u8) -> KeyOutput

Constructs a KeyOutput from a key code.

pub const fn from_key_code_with_modifiers( key_code: u8, key_modifiers: KeyboardModifiers, ) -> KeyOutput

Constructs a KeyOutput from a key code with the given keyboard modifiers.

pub const fn from_key_modifiers(key_modifiers: KeyboardModifiers) -> KeyOutput

Constructs a KeyOutput for just the given keyboard modifiers.

pub const fn from_consumer_code(usage_code: u8) -> KeyOutput

Constructs a KeyOutput from a consumer code.

pub const fn from_custom_code(custom_code: u8) -> KeyOutput

Constructs a KeyOutput from a custom code.

pub const fn from_mouse_output(mouse_output: MouseOutput) -> KeyOutput

Constructs a KeyOutput from a mouse output.

pub const fn key_code(&self) -> KeyUsage

Returns the key code value.

pub const fn key_modifiers(&self) -> KeyboardModifiers

Returns the keyboard modifiers of the key output.

pub const fn without_modifiers(self, suppress: KeyboardModifiers) -> KeyOutput

Returns a copy with the given modifier bits cleared.