Struct Key
pub struct Key<R> {
pub tap: R,
pub hold: R,
pub profile: u8,
pub hold_output: Option<KeyOutput>,
}Expand description
A key with tap-hold functionality.
Fields
tap: RThe ‘tap’ key.
hold: RThe ‘hold’ key.
profile: u8Behavior profile index: 0 = Config::default_profile; 1.. = Config::profiles.
hold_output: Option<KeyOutput>HID of the hold binding when it is a keyboard key that is safe to emit while pending.
Nickel fills this in keymap codegen
(ncl/smart_keys/tap_hold/keymap-codegen.ncl)
from the hold leaf.
LeftGUI / RightGUI and non-keyboard holds are None.
Used when Profile::pending_output is PendingOutput::Hold.
Implementations