pub struct Key<R> {
pub base: R,
pub morphed: R,
pub trigger_mods: KeyboardModifiers,
pub keep_mods: KeyboardModifiers,
}Expand description
A key that picks a nested binding based on held modifiers.
Fields
base: RBinding used when none of Self::trigger_mods are held.
morphed: RBinding used when any of Self::trigger_mods is held.
trigger_mods: KeyboardModifiersModifiers that activate the morphed binding (any-of).
keep_mods: KeyboardModifiersSubset of Self::trigger_mods to keep in the report on the morph path.
Implementations
Sourceimpl<R> Key<R>
impl<R> Key<R>
Sourcepub const fn new(
base: R,
morphed: R,
trigger_mods: KeyboardModifiers,
keep_mods: KeyboardModifiers,
) -> Key<R>
pub const fn new( base: R, morphed: R, trigger_mods: KeyboardModifiers, keep_mods: KeyboardModifiers, ) -> Key<R>
Constructs a mod-conditioned key.
Sourcepub const fn suppress_mods(&self) -> KeyboardModifiers
pub const fn suppress_mods(&self) -> KeyboardModifiers
Mods to suppress on the morph path (trigger \ keep).