pub struct KeyOutput { /* private fields */ }Expand description
Struct for the output from KeyState.
Implementations
Sourceimpl KeyOutput
impl KeyOutput
Sourcepub const fn from_usage(key_usage: KeyUsage) -> KeyOutput
pub const fn from_usage(key_usage: KeyUsage) -> KeyOutput
Constructs a KeyOutput from a key usage.
Sourcepub const fn from_usage_with_modifiers(
key_usage: KeyUsage,
key_modifiers: KeyboardModifiers,
) -> KeyOutput
pub const fn from_usage_with_modifiers( key_usage: KeyUsage, key_modifiers: KeyboardModifiers, ) -> KeyOutput
Constructs a KeyOutput from a key usage.
Sourcepub const fn from_key_code(key_code: u8) -> KeyOutput
pub const fn from_key_code(key_code: u8) -> KeyOutput
Constructs a KeyOutput from a key code.
Sourcepub const fn from_key_code_with_modifiers(
key_code: u8,
key_modifiers: KeyboardModifiers,
) -> KeyOutput
pub const fn from_key_code_with_modifiers( key_code: u8, key_modifiers: KeyboardModifiers, ) -> KeyOutput
Constructs a KeyOutput from a key code with the given keyboard modifiers.
Sourcepub const fn from_key_modifiers(key_modifiers: KeyboardModifiers) -> KeyOutput
pub const fn from_key_modifiers(key_modifiers: KeyboardModifiers) -> KeyOutput
Constructs a KeyOutput for just the given keyboard modifiers.
Sourcepub const fn from_consumer_code(usage_code: u8) -> KeyOutput
pub const fn from_consumer_code(usage_code: u8) -> KeyOutput
Constructs a KeyOutput from a consumer code.
Sourcepub const fn from_custom_code(custom_code: u8) -> KeyOutput
pub const fn from_custom_code(custom_code: u8) -> KeyOutput
Constructs a KeyOutput from a custom code.
Sourcepub const fn from_mouse_output(mouse_output: MouseOutput) -> KeyOutput
pub const fn from_mouse_output(mouse_output: MouseOutput) -> KeyOutput
Constructs a KeyOutput from a mouse output.
Sourcepub const fn key_modifiers(&self) -> KeyboardModifiers
pub const fn key_modifiers(&self) -> KeyboardModifiers
Returns the keyboard modifiers of the key output.
Sourcepub const fn without_modifiers(self, suppress: KeyboardModifiers) -> KeyOutput
pub const fn without_modifiers(self, suppress: KeyboardModifiers) -> KeyOutput
Returns a copy with the given modifier bits cleared.